
// Copyright 2015 ESRI
//
// All rights reserved under the copyright laws of the United States
// and applicable international laws, treaties, and conventions.
//
// You may freely redistribute and use this sample code, with or
// without modification, provided you include the original copyright
// notice and use restrictions.
//
// See the Sample code usage restrictions document for further information.
//

import QtQuick 2.3
import QtQuick.Controls 1.2
import QtPositioning 5.3
import QtQuick.Window 2.0
import ArcGIS.Extras 1.0
import ArcGIS.Runtime 10.26
import ArcGIS.Runtime.Toolkit.Controls 1.0
import "helpers.js" as JSHelpers

ApplicationWindow {
    id: appWindow
    width: 800
    height: 600
    title: "Demo Theater App"

    property double scaleFactor: System.displayScaleFactor

    property string runtimePath: System.userHomeFolder.filePath("ArcGIS/Runtime/Data/tpks")
    property string localTPK: runtimePath + "/Topographic.tpk"

    Portal {
        id: portal
        url: "http://www.arcgis.com"
    }

    PortalDownloadInfo {
        id: portalDownloadInfo
        portal: portal

        onRequestStatusChanged: {
            switch (requestStatus) {
            case Enums.PortalRequestStatusInProgress:
                break;
            case Enums.PortalRequestStatusCompleted:
                portalSearchParameters.query = info.basemapGalleryGroupQuery;
                portalSearchParameters.start = 1;
                portalSearchParameters.limit = 1;
                portalSearchGroups.portal = portal;
                portalSearchGroups.searchGroups(portalSearchParameters);
                break;
            case Enums.PortalRequestStatusErrored:
                break;
            }
        }

        Component.onCompleted: {
            downloadInfo();
        }
    }

    PortalSearchParameters {
        id: portalSearchParameters
    }

    PortalSearchGroups {
        id: portalSearchGroups
        onRequestStatusChanged: {
            switch (requestStatus) {
            case Enums.PortalRequestStatusInProgress:
                break;
            case Enums.PortalRequestStatusCompleted:
                if (portalSearchGroups.results.length > 0) {
                    portalSearchParameters.query = "group:" + portalSearchGroups.results[0].groupId;
                    portalSearchParameters.start = 1;
                    portalSearchParameters.limit = 100;
                    portalSearchItems.portal = portal;
                    portalSearchItems.searchItems(portalSearchParameters);
                }
                break;
            case Enums.PortalRequestStatusErrored:
                break;
            }
        }
    }

    PortalSearchItems {
        id: portalSearchItems
        onRequestStatusChanged: {
            switch (requestStatus) {
            case Enums.PortalRequestStatusInProgress:
                break;
            case Enums.PortalRequestStatusCompleted:
                break;
            case Enums.PortalRequestStatusErrored:
                console.log("Search Items - Error");
                break;
            }
        }
    }

    PortalDownloadItemInfo {
        id: portalDownloadItemInfo
        onRequestStatusChanged: {
            switch (requestStatus) {
            case Enums.PortalRequestStatusInProgress:
                break;
            case Enums.PortalRequestStatusCompleted:
                portalDownloadItemData.portal = portal;
                portalDownloadItemData.downloadItemData(portalDownloadItemInfo.itemInfo);
                break;
            case Enums.PortalRequestStatusErrored:
                break;
            }
        }
    }

    PortalDownloadItemData {
        id: portalDownloadItemData
        onRequestStatusChanged: {
            switch (requestStatus) {
            case Enums.PortalRequestStatusInProgress:
                break;
            case Enums.PortalRequestStatusCompleted:
                var webMap = JSON.parse(responseText);
                JSHelpers.loadWebMap(webMap);
                //loadWebMap(webMap);
                break;
            case Enums.PortalRequestStatusErrored:
                console.log("Download Item Data - Error");
                break;
            }
        }
    }

    FileInfo {
        id: tpkFile
        filePath: localTPK
    }

    Envelope {
        id: sanDiegoExtent
        xMin: -13055858.861260368
        yMin: 3845753.302202322
        xMax: -13025845.102165982
        yMax: 3873215.7484415015
    }

    /////////////////////////////////////////////////////////////////////////////////
    // TitleBar
    //
    TitleBar {
        id: titleBar
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }

        height: Qt.platform.os === "android" || Qt.platform.os === "ios" ? 40 * scaleFactor : 0
        visible: Qt.platform.os === "android" || Qt.platform.os === "ios"
    }

    /////////////////////////////////////////////////////////////////////////////////
    // Map
    //
    Map {
        id: map
        anchors {
            right: parent.right
            left: sideBar.right
            top: titleBar.bottom
            bottom: parent.bottom
        }

        PositionSource {
            id: position
        }

        NavigationToolbar {
            id: navToolbar
            anchors {
                top: parent.top
                right: parent.right
                margins: 10 * scaleFactor
            }
            visible: map.status === Enums.MapStatusReady
            homeButton.visible: false

            StyleButton {
                id: zoomSanDiego
                text: "S"

                onHoveredChanged: {
                    if (Qt.platform.os !== "android" && Qt.platform.os !== "ios") {
                        if (zoomSanDiego.hovered) {
                            navToolbar.stopFader();
                            zoomSanDiego.fader.stop();
                        } else {
                            navToolbar.startFader();
                            zoomSanDiego.fader.start();
                        }
                    }
                }
                onClicked: {
                    if (Qt.platform.os !== "android" && Qt.platform.os !== "ios") {
                        navToolbar.startFader();
                        zoomSanDiego.fader.start();
                    }

                    map.extent = sanDiegoExtent;
                }
            }
        }

        Button {
            id: offlineLayerButton

            anchors {
                bottom: parent.bottom
                margins: 5 * scaleFactor
            }

            text: "Offline Layer"
            visible: (Qt.platform.os === "ios" || Qt.platform.os === "android") && tpkFile.exists

            onClicked: {
                map.reset();

                var layer = ArcGISRuntime.createObject("ArcGISLocalTiledLayer", { "path": localTPK });
                map.addLayer(layer);
            }
        }

        onStatusChanged: {
            if (status === Enums.MapStatusReady)
                positionDisplay.positionSource = position;
        }
    }

    BasemapListView {
        id: sideBar
        anchors {
            top: titleBar.bottom
            bottom: parent.bottom
        }
    }

}

